@@ -34,7 +34,9 @@ struct key_mem_cache
 extern struct key_mem_cache *key_mem_cache_head;
 MUTEX_DECLARE_EXTERN(mem_cache_lock);
 
+#ifndef MIN
 #define MIN(a,b) ((a) < (b) ? (a) : (b))
+#endif
 
 #define BOOL(x)		((x) == 0) ? FALSE : TRUE
 #define INVBOOL(x)	((x) == 0) ? TRUE : FALSE
@@ -42,9 +44,16 @@ MUTEX_DECLARE_EXTERN(mem_cache_lock);
 #define TSS_PSFILE_INCREMENT_NUM_KEYS	1
 #define TSS_PSFILE_DECREMENT_NUM_KEYS	0
 
+#ifdef __GNUC__
+#define __no_optimize __attribute__((optimize("O0")))
+#else
+#define __no_optimize
+#endif
+
 void *calloc_tspi(TSS_HCONTEXT, UINT32);
 TSS_RESULT free_tspi(TSS_HCONTEXT, void *);
-TSS_RESULT add_mem_entry(TSS_HCONTEXT, void *);
+TSS_RESULT __tspi_add_mem_entry(TSS_HCONTEXT, void *);
+void * __tspi_memset(void *, int, size_t);
 
 /* secrets.c */
 
@@ -52,6 +61,7 @@ TSS_RESULT policy_UsesAuth(TSS_HPOLICY, TSS_BOOL *);
 
 TSS_RESULT secret_PerformAuth_OIAP(TSS_HOBJECT, UINT32, TSS_HPOLICY, TSS_BOOL, TCPA_DIGEST *,
 				   TPM_AUTH *);
+#if 0
 TSS_RESULT secret_PerformXOR_OSAP(TSS_HPOLICY, TSS_HPOLICY, TSS_HPOLICY, TSS_HOBJECT,
 				  UINT16, UINT32, TCPA_ENCAUTH *, TCPA_ENCAUTH *,
 				  BYTE *, TPM_AUTH *, TCPA_NONCE *);
@@ -62,6 +72,7 @@ TSS_RESULT secret_PerformAuth_OSAP(TSS_HOBJECT, UINT32, TSS_HPOLICY,
 TSS_RESULT secret_ValidateAuth_OSAP(TSS_HOBJECT, UINT32, TSS_HPOLICY,
 				    TSS_HPOLICY, TSS_HPOLICY, BYTE *,
 				    TPM_AUTH *, BYTE *, TCPA_NONCE *);
+#endif
 TSS_RESULT secret_TakeOwnership(TSS_HKEY, TSS_HTPM, TSS_HKEY, TPM_AUTH *,
 				UINT32 *, BYTE *, UINT32 *, BYTE *);
 
@@ -73,7 +84,7 @@ TSS_RESULT changeauth_encdata(TSS_HCONTEXT, TSS_HOBJECT, TSS_HOBJECT, TSS_HPOLIC
 TSS_RESULT sealx_mask_cb(PVOID, TSS_HKEY, TSS_HENCDATA, TSS_ALGORITHM_ID, UINT32, BYTE *, BYTE *,
 			 BYTE *, BYTE *, UINT32, BYTE *, BYTE *);
 
-TSS_RESULT free_resource(TSS_HCONTEXT, UINT32, UINT32);
+TSS_RESULT __tspi_free_resource(TSS_HCONTEXT, UINT32, UINT32);
 TSS_RESULT owner_get_pubek(TSS_HCONTEXT, TSS_HTPM, TSS_HKEY *);
 
 #define next( x )	x = x->next
@@ -132,8 +143,8 @@ TSS_RESULT get_local_random(TSS_HCONTEXT, TSS_BOOL, UINT32, BYTE **);
 
 extern TSS_VERSION VERSION_1_1;
 
-TSS_RESULT rsa_encrypt(TSS_HKEY, UINT32, BYTE*, UINT32*, BYTE*);
-TSS_RESULT rsa_verify(TSS_HKEY, UINT32, UINT32, BYTE*, UINT32, BYTE*);
+TSS_RESULT __tspi_rsa_encrypt(TSS_HKEY, UINT32, BYTE*, UINT32*, BYTE*);
+TSS_RESULT __tspi_rsa_verify(TSS_HKEY, UINT32, UINT32, BYTE*, UINT32, BYTE*);
 
 TSS_RESULT Init_AuthNonce(TCS_CONTEXT_HANDLE, TSS_BOOL, TPM_AUTH *);
 TSS_BOOL validateReturnAuth(BYTE *, BYTE *, TPM_AUTH *);
@@ -621,6 +632,8 @@ struct tcs_api_table {
 };
 
 extern struct tcs_api_table tcs_normal_api;
+#ifdef TSS_BUILD_TRANSPORT
 extern struct tcs_api_table tcs_transport_api;
+#endif
 
 #endif
