@@ -165,7 +165,8 @@ out:
 	/* cleanup in case of error */
 	if (rc != TCS_SUCCESS) {
 		if (hostname != NULL) {
-			tm->thread_data[thread_num].hostname = NULL;
+			if (thread_num != -1)
+				tm->thread_data[thread_num].hostname = NULL;
 			free(hostname);
 		}
 		close(socket);
@@ -195,145 +196,13 @@ thread_signal_init()
 		THREAD_EXIT(NULL);
 	}
 }
-#if 0
-void *
-tcsd_thread_run(void *v)
-{
-	struct tcsd_thread_data *data = (struct tcsd_thread_data *)v;
-	BYTE buffer[TCSD_TXBUF_SIZE];
-	struct tcsd_packet_hdr *ret_buf = NULL;
-	TSS_RESULT result;
-	int sizeToSend, sent_total, sent;
-	UINT64 offset;
-#ifndef TCSD_SINGLE_THREAD_DEBUG
-	int rc;
 
-	thread_signal_init();
-#endif
-
-	if ((data->buf_size = recv(data->sock, buffer, TCSD_TXBUF_SIZE, 0)) < 0) {
-		LogError("Failed Receive: %s", strerror(errno));
-		goto done;
-	}
-	LogDebug("Rx'd packet");
-
-	data->buf = buffer;
-
-	while (1) {
-		sent_total = 0;
-		if (data->buf_size > TCSD_TXBUF_SIZE) {
-			LogError("Packet received from socket %d was too large (%u bytes)",
-				 data->sock, data->buf_size);
-			goto done;
-		} else if (data->buf_size < (int)((2 * sizeof(UINT32)) + sizeof(UINT16))) {
-			LogError("Packet received from socket %d was too small (%u bytes)",
-				 data->sock, data->buf_size);
-			goto done;
-		}
-
-		if ((result = getTCSDPacket(data, &ret_buf)) != TSS_SUCCESS) {
-			/* something internal to the TCSD went wrong in preparing the packet
-			 * to return to the TSP.  Use our already allocated buffer to return a
-			 * TSS_E_INTERNAL_ERROR return code to the TSP. In the non-error path,
-			 * these LoadBlob's are done in getTCSDPacket().
-			 */
-			offset = 0;
-			/* load result */
-			LoadBlob_UINT32(&offset, result, buffer);
-			/* load packet size */
-			LoadBlob_UINT32(&offset, sizeof(struct tcsd_packet_hdr), buffer);
-			/* load num parms */
-			LoadBlob_UINT16(&offset, 0, buffer);
-
-			sizeToSend = sizeof(struct tcsd_packet_hdr);
-			LogDebug("Sending 0x%X bytes back", sizeToSend);
-
-			while (sent_total < sizeToSend) {
-				if ((sent = send(data->sock,
-						 &data->buf[sent_total],
-						 sizeToSend - sent_total, 0)) < 0) {
-					LogError("Packet send to TSP failed: send: %s. Thread exiting.",
-							strerror(errno));
-					goto done;
-				}
-				sent_total += sent;
-			}
-		} else {
-			sizeToSend = Decode_UINT32((BYTE *)&(ret_buf->packet_size));
-
-			LogDebug("Sending 0x%X bytes back", sizeToSend);
-
-			while (sent_total < sizeToSend) {
-				if ((sent = send(data->sock,
-						 &(((BYTE *)ret_buf)[sent_total]),
-						 sizeToSend - sent_total, 0)) < 0) {
-					LogError("response to TSP failed: send: %s. Thread exiting.",
-							strerror(errno));
-					free(ret_buf);
-					ret_buf = NULL;
-					goto done;
-				}
-				sent_total += sent;
-			}
-			free(ret_buf);
-			ret_buf = NULL;
-		}
-
-		if (tm->shutdown) {
-			LogDebug("Thread %zd exiting via shutdown signal!", THREAD_ID);
-			break;
-		}
-
-		/* receive the next packet */
-		if ((data->buf_size = recv(data->sock, buffer, TCSD_TXBUF_SIZE, 0)) < 0) {
-			LogError("TSP has closed its connection: %s. Thread exiting.",
-				 strerror(errno));
-			break;
-		} else if (data->buf_size == 0) {
-			LogDebug("The TSP has closed the socket's connection. Thread exiting.");
-			break;
-		}
-	}
-
-done:
-	/* Closing connection to TSP */
-	close(data->sock);
-	data->sock = -1;
-	data->buf = NULL;
-	data->buf_size = -1;
-	/* If the connection was not shut down cleanly, free TCS resources here */
-	if (data->context != NULL_TCS_HANDLE) {
-		TCS_CloseContext_Internal(data->context);
-		data->context = NULL_TCS_HANDLE;
-	}
-
-#ifndef TCSD_SINGLE_THREAD_DEBUG
-	MUTEX_LOCK(tm->lock);
-	tm->num_active_threads--;
-	/* if we're not in shutdown mode, then nobody is waiting to join this thread, so
-	 * detach it so that its resources are free at THREAD_EXIT() time. */
-	if (!tm->shutdown) {
-		if ((rc = THREAD_DETACH(*(data->thread_id)))) {
-			LogError("Thread detach failed (errno %d)."
-				 " Resources may not be properly released.", rc);
-		}
-	}
-	free(data->hostname);
-	data->hostname = NULL;
-	data->thread_id = THREAD_NULL;
-	MUTEX_UNLOCK(tm->lock);
-	THREAD_EXIT(NULL);
-#else
-	return NULL;
-#endif
-}
-#else
 void *
 tcsd_thread_run(void *v)
 {
 	struct tcsd_thread_data *data = (struct tcsd_thread_data *)v;
 	BYTE *buffer;
-	int recv_size, send_size;
+	int recd_so_far, empty_space, total_recv_size, recv_chunk_size, send_size;
 	TSS_RESULT result;
 	UINT64 offset;
 #ifndef TCSD_SINGLE_THREAD_DEBUG
@@ -346,38 +215,73 @@ tcsd_thread_run(void *v)
 	data->comm.buf = calloc(1, data->comm.buf_size);
 	while (data->comm.buf) {
 		/* get the packet header to get the size of the incoming packet */
-		buffer = data->comm.buf;
-		recv_size = sizeof(struct tcsd_packet_hdr);
-		if ((recv_size = recv_from_socket(data->sock, buffer, recv_size)) < 0)
+		if (recv_from_socket(data->sock, data->comm.buf,
+				     sizeof(struct tcsd_packet_hdr)) < 0)
 			break;
-		buffer += sizeof(struct tcsd_packet_hdr);       /* increment the buffer pointer */
+
+		recd_so_far = sizeof(struct tcsd_packet_hdr);
 
 		/* check the packet size */
-		recv_size = Decode_UINT32(data->comm.buf);
-		if (recv_size < (int)sizeof(struct tcsd_packet_hdr)) {
+		total_recv_size = Decode_UINT32(data->comm.buf);
+		if (total_recv_size < (int)sizeof(struct tcsd_packet_hdr)) {
 			LogError("Packet to receive from socket %d is too small (%d bytes)",
-					data->sock, recv_size);
+				 data->sock, total_recv_size);
 			break;
 		}
 
-		if (recv_size > (int) data->comm.buf_size ) {
+		LogDebug("total_recv_size %d, buf_size %u, recd_so_far %d", total_recv_size,
+			 data->comm.buf_size, recd_so_far);
+
+		empty_space = data->comm.buf_size - recd_so_far;
+
+		/* instead of blindly allocating recv_size bytes off the bat, stage the realloc
+		 * and wait for the data to come in over the socket. This protects against
+		 * trivially asking tcsd to alloc 2GB */
+		while (total_recv_size > (int) data->comm.buf_size) {
 			BYTE *new_buffer;
+			int new_bufsize;
 
-			LogDebug("Increasing communication buffer to %d bytes.", recv_size);
-			new_buffer = realloc(data->comm.buf, recv_size);
-			if (new_buffer == NULL) {
-				LogError("realloc of %d bytes failed.", recv_size);
-				break;
+			if ((int)data->comm.buf_size + TCSD_INCR_TXBUF_SIZE < total_recv_size) {
+				new_bufsize = data->comm.buf_size + TCSD_INCR_TXBUF_SIZE;
+				recv_chunk_size = empty_space + TCSD_INCR_TXBUF_SIZE;
+			} else {
+				new_bufsize = total_recv_size;
+				recv_chunk_size = total_recv_size - recd_so_far;
 			}
-			buffer = new_buffer + sizeof(struct tcsd_packet_hdr);
-			data->comm.buf_size = recv_size;
+
+			LogDebug("Increasing communication buffer to %d bytes.", new_bufsize);
+			new_buffer = realloc(data->comm.buf, new_bufsize);
+			if (new_buffer == NULL) {
+				LogError("realloc of %d bytes failed.", new_bufsize);
+				data->comm.buf = NULL;
+				goto no_mem_error;
+			}
+
+			data->comm.buf_size = new_bufsize;
 			data->comm.buf = new_buffer;
+			buffer = data->comm.buf + recd_so_far;
+
+			LogDebug("recv_chunk_size %d recd_so_far %d", recv_chunk_size, recd_so_far);
+			if (recv_from_socket(data->sock, buffer, recv_chunk_size) < 0) {
+				result = TCSERR(TSS_E_INTERNAL_ERROR);
+				goto error;
+			}
+
+			recd_so_far += recv_chunk_size;
+			empty_space = 0;
 		}
 
-		/* get the rest of the packet */
-		recv_size -= sizeof(struct tcsd_packet_hdr);    /* already received the header */
-		if ((recv_size = recv_from_socket(data->sock, buffer, recv_size)) < 0)
-			break;
+		if (recd_so_far < total_recv_size) {
+			buffer = data->comm.buf + recd_so_far;
+			recv_chunk_size = total_recv_size - recd_so_far;
+
+			LogDebug("recv_chunk_size %d recd_so_far %d", recv_chunk_size, recd_so_far);
+
+			if (recv_from_socket(data->sock, buffer, recv_chunk_size) < 0) {
+				result = TCSERR(TSS_E_INTERNAL_ERROR);
+				goto error;
+			}
+		}
 		LogDebug("Rx'd packet");
 
 		/* create a platform version of the tcsd header */
@@ -390,7 +294,9 @@ tcsd_thread_run(void *v)
 		UnloadBlob_UINT32(&offset, &data->comm.hdr.parm_size, data->comm.buf);
 		UnloadBlob_UINT32(&offset, &data->comm.hdr.parm_offset, data->comm.buf);
 
-		if ((result = getTCSDPacket(data)) != TSS_SUCCESS) {
+		result = getTCSDPacket(data);
+error:
+		if (result) {
 			/* something internal to the TCSD went wrong in preparing the packet
 			 * to return to the TSP.  Use our already allocated buffer to return a
 			 * TSS_E_INTERNAL_ERROR return code to the TSP. In the non-error path,
@@ -416,7 +322,7 @@ tcsd_thread_run(void *v)
 			break;
 		}
 	}
-
+no_mem_error:
 	LogDebug("Thread exiting.");
 
 	/* Closing connection to TSP */
@@ -453,5 +359,3 @@ tcsd_thread_run(void *v)
 #endif
 	return NULL;
 }
-
-#endif
